# Generated by Django 3.1.2 on 2020-10-28 01:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("unicef_security", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="user",
            name="first_name",
            field=models.CharField(
                blank=True, max_length=150, verbose_name="first name"
            ),
        ),
    ]
